package mapdemo;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * A demonstration of Java maps and enumerated types.
 *
 * <p>
 * File: <code>MapDemoMain.java</code>
 *
 * @see <a href="http://www.jblearning.com/catalog/9780763771447/"><i>Computer
 * Systems</i></a> publisher home page, <a
 * href="http://www.cslab.pepperdine.edu/warford/cosc330/">course</a> home page.
 * @author J. Stanley Warford
 */
public class MapDemoMain implements ActionListener {

    JFrame mainWindowFrame;
    JPanel inputPanel, buttonPanel;
    JLabel label;
    JTextField textField;
    JButton button;

    private static void createAndShowGUI() {
        JFrame.setDefaultLookAndFeelDecorated(true);
        MapDemoMain m = new MapDemoMain();
        // Set up the main window.
        m.mainWindowFrame = new JFrame("Java Map Demonstration");
        m.mainWindowFrame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        m.mainWindowFrame.setSize(new Dimension(240, 120));

        // Lay out the label and text field input panel from top to bottom.
        m.inputPanel = new JPanel();
        m.inputPanel.setLayout(new BoxLayout(inputPanel, BoxLayout.PAGE_AXIS));
        m.label = new JLabel("Enter a planet:");
        m.inputPanel.add(label);
        m.textField = new JTextField(20);
        m.inputPanel.add(textField);
        m.inputPanel.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));

        // Lay out the button from left to right.
        m.buttonPanel = new JPanel();
        m.buttonPanel.setLayout(new BoxLayout(buttonPanel, BoxLayout.LINE_AXIS));
        m.buttonPanel.setBorder(BorderFactory.createEmptyBorder(0, 10, 10, 10));
        m.buttonPanel.add(Box.createHorizontalGlue());
        m.button = new JButton("Enter");
        m.buttonPanel.add(button);
        m.buttonPanel.add(Box.createRigidArea(new Dimension(10, 0)));

        // Combine the input panel and the button panel in the main window.
        m.mainWindowFrame.add(inputPanel, BorderLayout.CENTER);
        m.mainWindowFrame.add(buttonPanel, BorderLayout.PAGE_END);

        m.textField.addActionListener(this);
        m.button.addActionListener(this);

        m.mainWindowFrame.pack();
        m.mainWindowFrame.setVisible(true);
    }

    public static void main(String[] args) {
        javax.swing.SwingUtilities.invokeLater(() -> createAndShowGUI());
    }

    @Override
    public void actionPerformed(ActionEvent event) {
        String line = textField.getText();
        if (Maps.planetTable.containsKey(line.toLowerCase())) {
            Planet planet = Maps.planetTable.get(line.toLowerCase());
            String planetString = Maps.planetStringTable.get(planet);
            switch (planet) {
                case P_MERCURY:
                case P_VENUS:
                    System.out.printf("%s is close to the sun.\n", planetString);
                    break;
                case P_EARTH:
                    System.out.printf("The %s is indeed a planet.\n", planetString);
                    break;
                case P_MARS:
                    System.out.printf("Planet %s is red.\n", planetString);
                    break;
                case P_JUPITER:
                case P_SATURN:
                    System.out.printf("%s is a big planet.\n", planetString);
                    break;
                case P_URANUS:
                case P_NEPTUNE:
                case P_PLUTO:
                    System.out.printf("%s is far from the sun.\n", planetString);
            }
            System.out.printf("Enumerated output: %s\n", planet);
            System.out.printf("Ordinal output: %d\n", planet.ordinal());
        } else {
            System.out.println(line + " is not a planet.");
        }
    }
}
